## ========================
## State distribution plot
## ========================

seqdplot <- function(seqdata, group=NULL, title=NULL, ...) {
	seqplot(seqdata, group=group, type="d", title=title, ...)
}
